#include "exports.h"

#include <qregexp.h>

#include "linkablemapobj.h"
#include "texteditor.h"


Export::Export()
{
	indentPerDepth="  ";
}

void Export::setPath (const QString &p)
{
	filepath=p;
}

void Export::setMapCenter(MapCenterObj *mc)
{
	mapCenter=mc;
}

QString Export::getSectionString(BranchObj *bostart)
{
	QString r;
	BranchObj *bo=bostart;
	int depth=bo->getDepth();
	while (depth>0)
	{
		r=QString("%1").arg(1+bo->getNum(),0,10)+"." + r;
		bo=(BranchObj*)(bo->getParObj());
		depth=bo->getDepth();
	}	
	if (r.isEmpty())
		return r;
	else	
		return r + " ";
}

void Export::exportMap()
{
	QFile file (filepath);
	if ( !file.open( IO_WriteOnly ) )
	{
		// FIXME experimental, testing
		cout << "Export::exportMap  couldn't open "<<filepath<<endl;
		return;
	}
	QTextStream ts( &file );	// use LANG decoding here...

	// Main loop over all branches
	QString s;
	QString actIndent("");
	int i;
	uint j;
	BranchObj *bo;
	bo=mapCenter->first();
	while (bo) 
	{
		// Make indentstring
		for (i=0;i<bo->getDepth();i++) actIndent+= indentPerDepth;

		// Write heading
		//	write (actIndent + getSectionString(bo) + bo->getHeading()+ "\n");
		if (bo->getDepth()==0)
		{
			ts << (bo->getHeading()+ "\n");
			for (j=0;j<bo->getHeading().length();j++) ts<<"=";
			ts << "\n";
		} else 	if (bo->getDepth()==1)
			ts << ("\n"+getSectionString(bo) + bo->getHeading()+ "\n");
		else	if (bo->getDepth()==2)
			ts << (actIndent + " o " + bo->getHeading()+ "\n");
		else	
			ts << (actIndent + " - " + bo->getHeading()+ "\n");
		
		// If necessary, write note
		if (!bo->getNote().isEmpty())
		{
			s =textConvertToASCII(bo->getNote());
			s=s.replace ("\n","\n"+actIndent);
			ts << (s+"\n\n");
		}
		
		bo=bo->next();
		actIndent="";
	}
	file.close();
}

// Exports a map to a LaTex file.  This file needs to be included or inported into a LaTex document
// it will not add a preamble, or anything that makes a full LaTex document.
void Export::exportLaTeX() 
{
  QFile file (filepath);
  if ( !file.open( IO_WriteOnly ) ) {
    // FIXME
    cout << "Export::exportMap  couldn't open "<<filepath<<endl;
    return;
  }
  QTextStream ts( &file );	// use LANG decoding here...
  ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
  
  // Main loop over all branches
  QString s;
  // QString actIndent("");
  // int i;
  BranchObj *bo;
  bo=mapCenter->first();
  while (bo) {
    if (bo->getDepth()==0);
    else if (bo->getDepth()==1) {
      ts << ("\\chapter{" + bo->getHeading()+ "}\n");
    }
    else if (bo->getDepth()==2) {
      ts << ("\\section{" + bo->getHeading()+ "}\n");
    }
    else if (bo->getDepth()==3) {
      ts << ("\\subsection{" + bo->getHeading()+ "}\n");
    }
    else if (bo->getDepth()==4) {
      ts << ("\\subsubsection{" + bo->getHeading()+ "}\n");
    }
    else {
      ts << ("\\paragraph*{" + bo->getHeading()+ "}\n");
    }
    
    // If necessary, write note
    if (!bo->getNote().isEmpty()) {
      ts << (textConvertToASCII(bo->getNote()));
      ts << ("\n");
    }
    
    bo=bo->next();
   }
  file.close();
}

#include "settings.h"

void Export::exportOOPresentation()
{
	QString templateDir="oo-test/suse-template/";
	QString templateContent="content.xml";
	QString tmpDir="/tmp/vym-ootest/";
	QString header="";


	// Create tmpdir
		// TODO

	// Copy template to tmpdir
		// TODO


	// Read content-template
		// TODO
	QString content;
	if (!loadStringFromDisk (templateDir+templateContent,content))
	{
		qWarning ("Export::exportOOPresentation() Couldn't load from "+templateDir+templateContent);
		return;
	}


	// Walk through map
	QString s;
	QString actIndent("");
	uint j;
	int i;
	BranchObj *bo;
	bo=mapCenter->first();
	while (bo) 
	{
		// Make indentstring
		for (i=0;i<bo->getDepth();i++) actIndent+= indentPerDepth;

		// Write heading
		//	write (actIndent + getSectionString(bo) + bo->getHeading()+ "\n");
		if (bo->getDepth()==0)
		{
			s+= (bo->getHeading()+ "\n");
			for (j=0;j<bo->getHeading().length();j++) s+="=";
			s+= "\n";
		} else 	if (bo->getDepth()==1)
			s+= ("\n"+getSectionString(bo) + bo->getHeading()+ "\n");
		else	if (bo->getDepth()==2)
			s+= (actIndent + " o " + bo->getHeading()+ "\n");
		else	
			s+ (actIndent + " - " + bo->getHeading()+ "\n");
		
		/*
		// If necessary, write note
		if (!bo->getNote().isEmpty())
		{
			s =textConvertToASCII(bo->getNote());
			s=s.replace ("\n","\n"+actIndent);
			ts << (s+"\n\n");
		}
		*/
		bo=bo->next();
		actIndent="";
	}

	
	// Insert new content
		// TODO
	cout <<"\n\ns="<<s<<endl;
	content.replace ("<!--INSERT PAGES HERE-->",s);
	cout << "ExportOO: content=\n"<<content<<endl;

	// zip tmpdir to destination
		// TODO

}

